# libpythonpro_valmeida90
Módulo para exemplificar construção de projetos Pythons no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto.

Link para o curso [Python Pro](https://www.python.pro.br/)

[![Updates](https://pyup.io/repos/github/valmeida90/libpythonpro_valmeida90/shield.svg)](https://pyup.io/repos/github/valmeida90/libpythonpro_valmeida90/)
[![Python 3](https://pyup.io/repos/github/valmeida90/libpythonpro_valmeida90/python-3-shield.svg)](https://pyup.io/repos/github/valmeida90/libpythonpro_valmeida90/)

Suportada versão 3 de Python

```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir a qualidade do código:
```console
flake8
```

Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip